@@ -20,11 +20,11 @@
 bzr_plugin_name = "tweet"
 
 # dev or final
-bzr_plugin_version = (1, 2, 0, "final", 0)
+bzr_plugin_version = (1, 3, 0, "final", 0)
 
-bzr_commands = ["twitter_auth","twitter_branchid"]
+bzr_commands = ["tweet-auth", "tweet-branchid"]
 
-bzr_compatible_versions = [(2, x, 0) for x in [5, 6]]
+bzr_compatible_versions = [(2, 5, 0), (2, 6, 0)]
 
 bzr_minimum_version = bzr_compatible_versions[0]
 bzr_maximum_version = bzr_compatible_versions[-1]
